.. currentmodule:: dnacentersdk

=============
dnacentersdk
=============

*Simple, lightweight, scalable Python API wrapper for the DNA Center APIs*

-------------------------------------------------------------------------------

Welcome to the docs!  dnacentersdk is a *community developed* Pythonic wrapping of the DNA Center APIs (for API versions: 1.2.10, 1.3.0).
The package represents all of the Cisco DNA Center API interactions via native Python tools.
Making working with the Cisco DNA Center APIs in Python a *native* and *natural* experience.

**dnacentersdk helps you get things done faster.**  We take care of the API semantics, and you can focus on writing your code.

With dnacentersdk, you can easily:

* Interact with the DNA Center APIs in an interactive Python session

* Quickly create code that enables you get something done in DNA Center

* Leverage the API wrapper to cleanly add DNA Center functionality to your project without having to write the boilerplate code for working with the DNA Center APIs

To *dive in* and see how dnacentersdk makes your life better, check out the
:ref:`Quickstart`!

The User Guide
==============

.. toctree::
    :maxdepth: 2

    installation
    api/intro
    api/quickstart
    api/api


The Development Community
=========================

Interested in contributing to the project?  Please review our community's Code of Conduct and then check out the Contributing page for info to help you get started.

.. toctree::
    :maxdepth: 1

    code_of_conduct
    contributing



General Information about the DNA Center Service
=================================================

What is DNA Center?
--------------------

    "A better way to control your network. Cisco DNA Center is the network management and command center for Cisco DNA, your intent-based network for the enterprise."

Visit the official `DNA Center`_ website for more information and to create a `free account`_!


DNA Center for Developers
--------------------------

Leveraging the DNA Center APIs and developing on top of the DNA Center cloud is easy.  Signup for a `free account`_ and then head over to the `DNA Center for Developers`_ website to learn more.


*Copyright (c) 2019 Cisco and/or its affiliates.*


.. _DNA Center: https://www.cisco.com/c/en/us/products/cloud-systems-management/dna-center/index.html
.. _free account: `DNA Center`_
.. _DNA Center for Developers: https://developer.cisco.com/site/networking/
.. _contribution: https://github.com/cisco-en-programmability/dnacentersdk#contribution
.. _dnacentersdk: https://github.com/cisco-en-programmability/dnacentersdk
